powered by
H: sensible heat flux density (W / m^2)
.get_H(T_leaf, pars, unitless)
Leaf temperature in Kelvin
Concatenated parameters (leaf_par, enviro_par, and constants)
leaf_par
enviro_par
constants
Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.
units
Value in W / m\(^2\) of class units
$$H = P_\mathrm{a} c_p g_\mathrm{h} (T_\mathrm{leaf} - T_\mathrm{air})$$
c_p
g_h
P_a
T_air
.get_gh, .get_Pa
.get_gh
.get_Pa
# NOT RUN { library(tealeaves) cs <- make_constants() ep <- make_enviropar() lp <- make_leafpar() T_leaf <- set_units(298.15, K) tealeaves:::.get_H(T_leaf, c(cs, ep, lp), FALSE) # }
Run the code above in your browser using DataLab