Learn R Programming

tealeaves (version 1.0.3)

.get_L: L: Latent heat flux density (W / m^2)

Description

L: Latent heat flux density (W / m^2)

Usage

.get_L(T_leaf, pars, unitless)

Arguments

T_leaf

Leaf temperature in Kelvin

pars

Concatenated parameters (leaf_par, enviro_par, and constants)

unitless

Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.

Value

Value in W / m^2 of class units

Details

$$L = h_\mathrm{vap} g_\mathrm{tw} d_\mathrm{wv}$$

Symbol R Description Units Default
\(d_\mathrm{wv}\) d_wv water vapour gradient mol / m ^ 3 calculated
\(h_\mathrm{vap}\) h_vap latent heat of vaporization J / mol calculated

Examples

Run this code
# NOT RUN {
library(tealeaves)

cs <- make_constants()
ep <- make_enviropar()
lp <- make_leafpar()

T_leaf <- set_units(298.15, K)

tealeaves:::.get_L(T_leaf, c(cs, ep, lp), FALSE)

# }

Run the code above in your browser using DataLab