Learn R Programming

tealeaves (version 1.0.3)

.get_dwv: d_wv: water vapour gradient (mol / m ^ 3)

Description

d_wv: water vapour gradient (mol / m ^ 3)

Usage

.get_dwv(T_leaf, pars, unitless)

Arguments

T_leaf

Leaf temperature in Kelvin

pars

Concatenated parameters (leaf_par, enviro_par, and constants)

unitless

Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.

Value

Value in mol / m^3 of class units

Details

Water vapour gradient: The water vapour pressure differential from inside to outside of the leaf is the saturation water vapor pressure inside the leaf (p_leaf) minus the water vapor pressure of the air (p_air):

$$d_\mathrm{wv} = p_\mathrm{leaf} / (R T_\mathrm{leaf}) - RH p_\mathrm{air} / (R T_\mathrm{air})$$

Note that water vapor pressure is converted from kPa to mol / m^3 using ideal gas law.

Symbol R Description Units Default
\(p_\mathrm{air}\) p_air saturation water vapour pressure of air kPa calculated
\(p_\mathrm{leaf}\) p_leaf saturation water vapour pressure inside the leaf kPa calculated
\(R\) R ideal gas constant J / (mol K) 8.3144598
\(\mathrm{RH}\) RH relative humidity % 0.50
\(T_\mathrm{air}\) T_air air temperature K 298.15

Examples

Run this code
# NOT RUN {
# Water vapour gradient: 

leaf_par <- make_leafpar()
enviro_par <- make_enviropar()
constants <- make_constants()
pars <- c(leaf_par, enviro_par, constants)
T_leaf <- set_units(300, K)
T_air <- set_units(298.15, K)
p_leaf <- set_units(35.31683, kPa)
p_air <- set_units(31.65367, kPa)

d_wv <- p_leaf / (pars$R * T_leaf) - pars$RH * p_air / (pars$R * T_air)

# }

Run the code above in your browser using DataLab