Learn R Programming

tealeaves (version 1.0.3)

.get_gbw: g_bw: Boundary layer conductance to water vapour (m / s)

Description

g_bw: Boundary layer conductance to water vapour (m / s)

Usage

.get_gbw(T_leaf, surface, pars, unitless)

Arguments

T_leaf

Leaf temperature in Kelvin

surface

Leaf surface (lower or upper)

pars

Concatenated parameters (leaf_par, enviro_par, and constants)

unitless

Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.

Value

Value in m / s of class units

Details

$$g_\mathrm{bw} = D_\mathrm{w} Sh / d$$

Symbol R Description Units Default
\(d\) leafsize Leaf characteristic dimension in meters m 0.1
\(D_\mathrm{w}\) D_w diffusion coefficient for water vapour m\(^2\) / s calculated

Examples

Run this code
# NOT RUN {
library(tealeaves)

cs <- make_constants()
ep <- make_enviropar()
lp <- make_leafpar()

T_leaf <- set_units(298.15, K)

tealeaves:::.get_gbw(T_leaf, "lower", c(cs, ep, lp), FALSE)

# }

Run the code above in your browser using DataLab