Learn R Programming

tealeaves (version 1.0.3)

.get_gr: Gr: Grashof number

Description

Gr: Grashof number

Usage

.get_gr(T_leaf, pars, unitless)

Arguments

T_leaf

Leaf temperature in Kelvin

pars

Concatenated parameters (leaf_par, enviro_par, and constants)

unitless

Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.

Value

A unitless number of class units

Details

$$Gr = t_\mathrm{air} G d ^ 3 |T_\mathrm{v,leaf} - T_\mathrm{v,air}| / D_\mathrm{m} ^ 2$$

Symbol R Description Units Default
\(d\) leafsize Leaf characteristic dimension in meters m 0.1
\(D_\mathrm{m}\) D_m diffusion coefficient of momentum in air m\(^2\) / s calculated
\(G\) G gravitational acceleration m / s\(^2\) 9.8
\(t_\mathrm{air}\) t_air coefficient of thermal expansion of air 1 / K 1 / Temp
\(T_\mathrm{v,air}\) Tv_air virtual air temperature K calculated

Examples

Run this code
# NOT RUN {
library(tealeaves)

cs <- make_constants()
ep <- make_enviropar()
lp <- make_leafpar()

T_leaf <- set_units(298.15, K)

tealeaves:::.get_gr(T_leaf, c(cs, ep, lp), FALSE)

# }

Run the code above in your browser using DataLab