Learn R Programming

tealeaves (version 1.0.3)

.get_nu: Nu: Nusselt number

Description

Nu: Nusselt number

Usage

.get_nu(T_leaf, surface, pars, unitless)

Arguments

T_leaf

Leaf temperature in Kelvin

surface

Leaf surface (lower or upper)

pars

Concatenated parameters (leaf_par, enviro_par, and constants)

unitless

Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.

Value

A unitless number of class units

Details

The Nusselt number depends on a combination how much free or forced convection predominates. For mixed convection:

$$Nu = (a Re ^ b) ^ {3.5} + (c Gr ^ d) ^ {3.5}) ^ {1 / 3.5}$$

Symbol R Description Units Default
\(a, b, c, d\) a, b, c, d empirical coefficients none calculated
\(Gr\) Gr Grashof number none calculated

Examples

Run this code
# NOT RUN {
library(tealeaves)

cs <- make_constants()
ep <- make_enviropar()
lp <- make_leafpar()

T_leaf <- set_units(298.15, K)

tealeaves:::.get_nu(T_leaf, "lower", c(cs, ep, lp), FALSE)

# }

Run the code above in your browser using DataLab