Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.
Value
Value in kPa of class units
Details
Goff-Gratch equation (see http://cires1.colorado.edu/~voemel/vp.html)
This equation assumes P = 1 atm = 101.3246 kPa, otherwise boiling temperature needs to change