Concatenated parameters (leaf_par, enviro_par, and constants)
unitless
Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.
Value
A unitless number of class units
Details
The Sherwood number depends on a combination how much free or forced convection predominates. For mixed convection:
$$Sh = (a Re ^ b) ^ {3.5} + (c Gr ^ d) ^ {3.5}) ^ {1 / 3.5}$$