Learn R Programming

tealeaves (version 1.0.3)

Ar: Ar: Archimedes number

Description

Ar: Archimedes number

Usage

Ar(T_leaf, pars, unitless = FALSE)

Arguments

T_leaf

Leaf temperature in Kelvin

pars

Concatenated parameters (leaf_par, enviro_par, and constants)

unitless

Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.

Value

unitless = TRUE: A unitless number of class numeric unitless = FALSE: A unitless number of class units Also returns Reynolds and Grashof numbers

Details

The Archimedes number is a dimensionless number that describes when free or forced convection dominates.

$$Ar = Gr / Re ^ 2$$

Symbol R Description Units Default
\(Gr\) Gr Grashof number none calculated

Examples

Run this code
# NOT RUN {
cs <- make_constants()
ep <- make_enviropar()
lp <- make_leafpar()
pars <- c(cs, lp, ep)
T_leaf <- set_units(298.15, "K")

Ar(T_leaf, pars)

# }

Run the code above in your browser using DataLab