Learn R Programming

tealeaves (version 1.0.7)

enviro_par: Environmental parameters

Description

This function ensures that environmental parameter inputs are properly formatted.

Usage

enviro_par(.x)

Arguments

.x

A list to be constructed into enviro_par. If units are not provided, they will be set without conversion. If units are provided, they will be checked and converted to units that tealeaves uses.

Details

Constructor for the S3 class "enviro_par".