powered by
Re: Reynolds number
.get_re(T_leaf, pars, unitless)
Leaf temperature in Kelvin
Concatenated parameters (leaf_par, enviro_par, and constants)
leaf_par
enviro_par
constants
Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.
units
A unitless number of class units
$$Re = u d / D_\mathrm{m}$$
leafsize
D_m
# NOT RUN { library(tealeaves) cs <- make_constants() ep <- make_enviropar() lp <- make_leafpar() T_leaf <- set_units(298.15, K) tealeaves:::.get_re(T_leaf, c(cs, ep, lp), FALSE) # }
Run the code above in your browser using DataLab