Concatenated parameters (leaf_par, enviro_par, and constants)
unitless
Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.
Value
unitless = TRUE: A unitless number of class numericunitless = FALSE: A unitless number of class units
Also returns Reynolds and Grashof numbers
Details
The Archimedes number is a dimensionless number that describes when free or forced convection dominates.