Concatenated parameters (leaf_par, enviro_par, and constants)
unitless
Logical. Should function use parameters with units? The function is faster when FALSE, but input must be in correct units or else results will be incorrect without any warning.
Value
unitless = TRUE: A value in units of mol / (m ^ 2 / s) number of class numericunitless = FALSE: A value in units of mol / (m ^ 2 / s) of class units
Details
The leaf evaporation rate is the product of the total conductance to water vapour (m / s) and the water vapour gradient (mol / m^3):
$$E = g_\mathrm{tw} D_\mathrm{wv}$$
If unitless = TRUE, T_leaf is assumed in degrees K without checking.